@@ -17,7 +17,7 @@ import arviz
 __all__ = ['ReactiveAffineInvariantSampler']
 __author__ = """Johannes Buchner"""
 __email__ = 'johannes.buchner.acad@gmx.com'
-__version__ = '0.3.1'
+__version__ = '0.4.1'
 
 
 # Some parts are from the nnest library by Adam Moss (https://github.com/adammoss/nnest)
@@ -286,7 +286,7 @@ class ReactiveAffineInvariantSampler(object):
             ncall_here += getattr(sampler, 'ncall', num_steps * num_walkers)
 
         if self.use_mpi:
-            recv_ncall = self.comm.gather(self.ncall, root=0)
+            recv_ncall = self.comm.gather(ncall_here, root=0)
             ncall_here = sum(self.comm.bcast(recv_ncall, root=0))
 
         assert ncall_here > 0, ncall_here
@@ -307,6 +307,7 @@ class ReactiveAffineInvariantSampler(object):
                     self.logger.debug(
                         "acceptance rates: %s%% (worst few)", 
                         (accepts[i[:8]] * 100. / (num_steps - 1)).astype(int))
+                flat_chain = sampler.get_chain(flat=True)
                 
                 # diagnose this chain
                 
@@ -338,8 +339,8 @@ class ReactiveAffineInvariantSampler(object):
                         break
 
                     # secondly, detect drift with geweke
-                    a = sampler.get_chain(flat=True)[:num_steps // 4, i]
-                    b = sampler.get_chain(flat=True)[-num_steps // 4:, i]
+                    a = flat_chain[:len(flat_chain) // 4, i]
+                    b = flat_chain[-len(flat_chain) // 4:, i]
                     geweke_z = (a.mean() - b.mean()) / (np.var(a) + np.var(b))**0.5
                     if geweke_z > geweke_max:
                         self.logger.debug("geweke drift (z=%.1f) detected for parameter '%s'" % (geweke_z, self.paramnames[i]))
